@@ -145,7 +145,28 @@
 		     (string-match "XEmacs" emacs-version)))
 
 (sysdep-defconst window-system nil)
-(sysdep-defconst window-system-version 0)
+
+(sysdep-defvar x-library-search-path '("/usr/X11R6/lib/X11/"
+				       "/usr/X11R5/lib/X11/"
+				       "/usr/lib/X11R6/X11/"
+				       "/usr/lib/X11R5/X11/"
+				       "/usr/local/X11R6/lib/X11/"
+				       "/usr/local/X11R5/lib/X11/"
+				       "/usr/local/lib/X11R6/X11/"
+				       "/usr/local/lib/X11R5/X11/"
+				       "/usr/X11/lib/X11/"
+				       "/usr/lib/X11/"
+				       "/usr/local/lib/X11/"
+				       "/usr/X386/lib/X11/"
+				       "/usr/x386/lib/X11/"
+				       "/usr/XFree86/lib/X11/"
+				       "/usr/unsupported/lib/X11/"
+				       "/usr/athena/lib/X11/"
+				       "/usr/local/x11r5/lib/X11/"
+				       "/usr/lpp/Xamples/lib/X11/"
+				       "/usr/openwin/lib/X11/"
+				       "/usr/openwin/share/lib/X11/")
+  "Search path used for X11 libraries.")
 
 ;; frame-related stuff.
 
@@ -302,7 +323,7 @@ BEFORE, if provided, is the name of a menu item before which this item should
    ((fboundp 'ns-display-color-cells) 'ns-display-color-celles)
    (t 'ignore)))
 
-(sysdep-defun try-font-name (fontname)
+(sysdep-defun try-font-name (fontname &rest args)
   (car-safe (x-list-fonts fontname)))
 
 (sysdep-defalias 'device-pixel-width
@@ -388,6 +409,17 @@ Value is `tty' for a tty device (a character-only terminal),
   (or window-system 'tty))
 
 ;; misc
+(sysdep-defun match-string (num &optional string)
+  "Return string of text matched by last search.
+NUM specifies which parenthesized expression in the last regexp.
+ Value is nil if NUMth pair didn't match, or there were less than NUM pairs.
+Zero means the entire text matched by the whole regexp or whole string.
+STRING should be given if the last search was by `string-match' on STRING."
+  (if (match-beginning num)
+      (if string
+	  (substring string (match-beginning num) (match-end num))
+	(buffer-substring (match-beginning num) (match-end num)))))
+
 (sysdep-defun add-hook (hook-var function &optional at-end)
   "Add a function to a hook.
 First argument HOOK-VAR (a symbol) is the name of a hook, second
@@ -499,6 +531,9 @@ Returns nil if FUNCTION was already present in HOOK-VAR, else new
 		  (prin1 error-object stream))))
 	   error-object stream))
 
+(sysdep-defun find-face (face)
+  (car-safe (memq face (face-list))))
+
 ;; window functions
 
 ;; not defined in v18
