@@ -1,7 +1,7 @@
 ;;; w3-vars.el,v --- All variable definitions for emacs-w3
 ;; Author: wmperry
-;; Created: 1995/08/25 01:07:18
-;; Version: 1.163
+;; Created: 1995/10/15 19:58:42
+;; Version: 1.171
 ;; Keywords: comm, help, hypermedia
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -28,7 +28,7 @@
 ;;; Variable definitions for w3
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 (defconst w3-version-number
-  (let ((x "p2-2-16"))
+  (let ((x "p2-2-25"))
     (if (string-match "State:[ \t\n]+.\\([^ \t\n]+\\)" x)
 	(setq x (substring x (match-beginning 1) (match-end 1)))
       (setq x (substring x 1)))
@@ -36,7 +36,7 @@
      (function (lambda (x) (if (= x ?-) "." (char-to-string x)))) x ""))
   "Version # of w3-mode.")
 
-(defconst w3-version-date (let ((x "1995/08/25 01:07:18"))
+(defconst w3-version-date (let ((x "1995/10/15 19:58:42"))
 			    (if (string-match "Date: \\([^ \t\n]+\\)" x)
 				(substring x (match-beginning 1) (match-end 1))
 			      x))
@@ -315,11 +315,22 @@ formatting in my biased opinion.")
 home pages, link colors, etc.  If non-nil, then `w3-netscape-configuration-file'
 is read in at startup.")
 
+(defvar w3-honor-stylesheets t
+  "*Whether to let a document specify a CSS stylesheet.")
+
 (defvar w3-user-colors-take-precedence nil
   "*Whether to let a document define certain colors about itself.
 Like foreground and background colors and pixmaps, color of links and
 visited links, etc.")
 
+(defvar w3-gc-cons-threshold-multiplier 1
+  "Amount to temporarily multiply gc-cons-threshold by when parsing HTML.
+Setting this to a number greater than 1 will result in less frequent
+garbage collections when parsing an HTML document, which may often speed
+up handling of a large document with many elements.  The disadvantage is
+that it allows Emacs's total memory usage to grow larger, which may result
+in later garbage collections taking more time.")
+
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;; Hook Variables
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -431,6 +442,8 @@ the buffer.")
     ("image/x-pixmap"         . "cat ")
     ("image/x-xpixmap"        . "cat ")
     ("image/pict"             . "picttoppm | %s")
+    ("image/x-rgb"            . "sgitopnm | %s")
+    ("image/x-sgi"            . "sgitopnm | %s")
     ("image/x-macpaint"       . "macptopbm | %s")
     ("image/x-targa"          . "tgatoppm  | %s")
     ("image/tiff"             . "tifftopgm | pgmtoppm | %s")
@@ -511,14 +524,12 @@ begin and end characters.")
     (h5 . (nil ?= nil))
     (h6 . (nil ?: nil)))
   "*An assoc list of header tags and a list of formatting instructions.
-This list consists of 3 items - the first item is a character that is
-inserted before the header X number of times, where X is the length of
-the header.  A <BR> is automatically inserted after this.
-The second item is the character to insert after the header.  A <BR>
-is inserted before and after this string. And the third is a function
-to call on the region between the start and end of the header.  This
-will be called with 2 arguments, the buffer positions of the start and
-end of the headers.")
+This list consists of 3 items - the first item is no longer used.  The
+second item is the character to insert after the header.  A <BR> is
+inserted before and after this string. And the third is a function to
+call on the region between the start and end of the header.  This will
+be called with 2 arguments, the buffer positions of the start and end
+of the headers.")
 
 (defvar w3-list-chars-assoc 
   '(
@@ -537,10 +548,12 @@ should be used for.  n starts at 1.")
  ((or w3-running-epoch w3-running-FSF19 w3-running-xemacs)
   (defvar w3-node-style 'w3-node-style "Face used for hypertext links.")
   (defvar w3-default-style 'w3-default-style "Default face.")
-  (defvar w3-visited-node-style 'w3-visited-node-style "Visited links."))
+  (defvar w3-visited-node-style 'w3-visited-node-style "Visited links.")
+  (defvar w3-active-node-style 'w3-active-node-style "Active links."))
  (t
   (defvar w3-node-style nil)
   (defvar w3-default-style nil)
+  (defvar w3-active-node-style nil)
   (defvar w3-visited-node-style nil)))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -928,6 +941,7 @@ the default face or not).")
     w3-graphic
     zone
     label-text
+    seen-this-url
     )
   "A list of all the various state kept in the drawing engine.
 This is used by the `w3-get-state' and `w3-put-state' macros.")
@@ -1067,6 +1081,7 @@ returns.")
     w3-hidden-forms
     w3-invisible-href-list
     w3-node-style
+    w3-active-node-style
     w3-state-vector
     w3-visited-node-style
     w3-form-labels
